@@ -1,9 +1,9 @@
 package Music::Cadence;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Provide musical cadence chords
+# ABSTRACT: Generate musical cadence chords
 
-our $VERSION = '0.1001';
+our $VERSION = '0.1002';
 
 use Moo;
 use Music::Chord::Note;
@@ -143,22 +143,18 @@ sub _invert_chord {
         $chord = $mcp->chord_inv( $chord, inv_num => $inversion );
     }
     else {
-        # Perform gymnastics to convert from named notes to inverted named notes
-        my $notes = $chord;
-
-        $notes = [ grep { s/\d+// } @$notes ]
+        # Perform gymnastics to convert named notes to inverted named notes
+        $chord = [ grep { s/\d+// } @$chord ]
             if $octave;
 
-        my @pitches = map { Music::Note->new( $_ . -1, 'ISO' )->format('midinum') } @$notes;
+        my $pitches = [ map { Music::Note->new( $_ . -1, 'ISO' )->format('midinum') } @$chord ];
 
-        my $inverted = $mcp->chord_inv( \@pitches, inv_num => $inversion );
+        $pitches = $mcp->chord_inv( $pitches, inv_num => $inversion );
 
-        $notes = [ map { Music::Note->new( $_, 'midinum' )->format('isobase') } @$inverted ];
+        $chord = [ map { Music::Note->new( $_, 'midinum' )->format('isobase') } @$pitches ];
 
-        $notes = [ map { $_ . $octave } @$notes ]
+        $chord = [ map { $_ . $octave } @$chord ]
             if $octave;
-
-        $chord = $notes;
     }
 
     return $chord;
@@ -219,11 +215,11 @@ __END__
 
 =head1 NAME
 
-Music::Cadence - Provide musical cadence chords
+Music::Cadence - Generate musical cadence chords
 
 =head1 VERSION
 
-version 0.1001
+version 0.1002
 
 =head1 SYNOPSIS
 
@@ -283,7 +279,7 @@ version 0.1001
 
 =head1 DESCRIPTION
 
-C<Music::Cadence> provides a pair of musical cadence chords.
+C<Music::Cadence> generates a pair of musical cadence chords.
 
 These chords are usually added to the end of a musical phrase, and
 are used to suggest a sense of anticipation, pause, finality, etc.
